.. currentmodule:: sardana.pool.poolmetacontroller

:mod:`~sardana.pool.poolmetacontroller`
=======================================

.. automodule:: sardana.pool.poolmetacontroller

.. rubric:: Classes

.. hlist::
    :columns: 3

    * :class:`DataInfo`
    * :class:`TypeData`
    * :class:`ControllerLibrary`
    * :class:`ControllerClass`

DataInfo
-------------------

.. inheritance-diagram:: DataInfo
    :parts: 1
    
.. autoclass:: DataInfo
    :show-inheritance:
    :members:
    :undoc-members:

TypeData
-------------------

.. inheritance-diagram:: TypeData
    :parts: 1
    
.. autoclass:: TypeData
    :show-inheritance:
    :members:
    :undoc-members:
    
ControllerLib
-------------------

.. inheritance-diagram:: ControllerLibrary
    :parts: 1
    
.. autoclass:: ControllerLibrary
    :show-inheritance:
    :members:
    :undoc-members:

ControllerClass
-------------------

.. inheritance-diagram:: ControllerClass
    :parts: 1
    
.. autoclass:: ControllerClass
    :show-inheritance:
    :members:
    :undoc-members:

.. rubric:: Constants

.. autodata:: CONTROLLER_TEMPLATE

.. autodata:: CTRL_TYPE_MAP

.. autodata:: TYPE_MAP

.. autodata:: TYPE_MAP_OBJ

